@@ -353,15 +353,13 @@ class Client(Singleton):
         else:
             self.redis.delkey(task_id)
         
-        connection = await self.mq.get_mq_conn()
         try:
             ret = await self.mq.async_publish(self.get_topic, {
                 'bucket': bucket,
                 'bucket_name': bucket_name,
                 'refresh': 'yes' if refresh else 'no'
-            }, mq=connection)
+            })
             if ret:
-                await connection.close()
                 t = time.time()
                 resp = None
                 while True:
@@ -378,9 +376,6 @@ class Client(Singleton):
                     await asyncio.sleep(1/30)
         except Exception as e:
             return False, '获取失败'
-        finally:
-            if not connection.is_closed:
-                await connection.close()
 
     async def get_mq_conn(self):
         return await self.mq.get_mq_conn()
@@ -388,16 +383,14 @@ class Client(Singleton):
     async def put_from_cloud_async(self, url, bucket, bucket_name, timeout=10, file_ttl=-1):
         # save to cache
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
-        connection = await self.mq.get_mq_conn()
         try:
             ret = await self.mq.async_publish(self.put_topic, {
                 'url': url,
                 'bucket': bucket,
                 'bucket_name': bucket_name,
                 'ttl': file_ttl
-            }, connection)
+            })
             if ret:
-                await connection.close()
                 t = time.time()
                 while True:
                     if time.time() - t >= timeout:
@@ -416,9 +409,6 @@ class Client(Singleton):
             return False, '上传出错'
         except Exception as e:
             return False, str(e)
-        finally:
-            if not connection.is_closed:
-                await connection.close()
         
     
     async def put_async(self, path, bucket, bucket_name, timeout=10, file_ttl=-1):
