@@ -70,13 +70,13 @@ patch_frame_config(
 
 hmfs_client = Client.get_client(opt.api_host, cache_engine.client, None)
 
-@task_deco('fs_put', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
+@task_deco('fs_put', function_timeout=20, concurrent_mode=4, concurrent_num=4, broker_kind=BrokerEnum.NSQ, specify_async_loop=asyncio.get_event_loop())
 async def file_transfer_put(url, bucket, bucket_name, ttl):
     key = 'file_transfer_put_{}_{}'.format(bucket, bucket_name)
     if await cache_engine.get_cache_async(key, return_obj=False) is not None:
         return
     
-    with cache_engine.lock(key, ttl=30) as lock:
+    with cache_engine.lock(key, ttl=10) as lock:
         if lock:
             try:
                 if await cache_engine.get_cache_async(key, return_obj=False) is not None:
@@ -125,7 +125,7 @@ async def file_transfer_put(url, bucket, bucket_name, ttl):
                     }, expired=60)
 
 
-@task_deco('fs_get', function_timeout=60, concurrent_mode=4, broker_kind=BrokerEnum.NSQ)
+@task_deco('fs_get', function_timeout=60, concurrent_mode=4, concurrent_num=4, broker_kind=BrokerEnum.NSQ)
 async def file_transfer_get(bucket, bucket_name, refresh='no'):
     try:
         task_id = 'tmp_file_{}_{}'.format(bucket, bucket_name)
